@@ -412,7 +412,9 @@ void DownloadThread::run()
     /* Deal with badly configured HTTP servers that terminate the connection quickly
        if connections stalls for some seconds while kernel commits buffers to slow SD card.
        And also reconnect if we detect from our end that transfer stalled for more than one minute */
-    while (ret == CURLE_PARTIAL_FILE || ret == CURLE_OPERATION_TIMEDOUT || (ret == CURLE_RECV_ERROR && _lastDlNow != _lastFailureOffset) )
+    while (ret == CURLE_PARTIAL_FILE || ret == CURLE_OPERATION_TIMEDOUT
+           || (ret == CURLE_HTTP2_STREAM && _lastDlNow != _lastFailureOffset)
+           || (ret == CURLE_RECV_ERROR && _lastDlNow != _lastFailureOffset) )
     {
         time_t t = time(NULL);
         qDebug() << "HTTP connection lost. Time:" << t;
@@ -444,23 +446,7 @@ void DownloadThread::run()
             break;
         case CURLE_WRITE_ERROR:
             deleteDownloadedFile();
-
-#ifdef Q_OS_WIN
-            if (_file.errorCode() == ERROR_ACCESS_DENIED)
-            {
-                QString msg = tr("Access denied error while writing file to disk.");
-                QSettings registry("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows Defender\\Windows Defender Exploit Guard\\Controlled Folder Access",
-                                   QSettings::Registry64Format);
-                if (registry.value("EnableControlledFolderAccess").toInt() == 1)
-                {
-                    msg += "<br>"+tr("Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.");
-                }
-                _onDownloadError(msg);
-            }
-            else
-#endif
-            if (!_cancelled)
-                _onDownloadError(tr("Error writing file to disk"));
+            _onWriteError();
             break;
         case CURLE_ABORTED_BY_CALLBACK:
             deleteDownloadedFile();
@@ -671,6 +657,26 @@ void DownloadThread::_onDownloadError(const QString &msg)
     emit error(msg);
 }
 
+void DownloadThread::_onWriteError()
+{
+#ifdef Q_OS_WIN
+    if (_file.errorCode() == ERROR_ACCESS_DENIED)
+    {
+        QString msg = tr("Access denied error while writing file to disk.");
+        QSettings registry("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows Defender\\Windows Defender Exploit Guard\\Controlled Folder Access",
+                           QSettings::Registry64Format);
+        if (registry.value("EnableControlledFolderAccess").toInt() == 1)
+        {
+            msg += "<br>"+tr("Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.");
+        }
+        _onDownloadError(msg);
+    }
+    else
+#endif
+    if (!_cancelled)
+        _onDownloadError(tr("Error writing file to disk"));
+}
+
 void DownloadThread::_closeFiles()
 {
     _file.close();
@@ -726,7 +732,7 @@ void DownloadThread::_writeComplete()
 
     emit finalizing();
 
-    if (!_config.isEmpty() || !_cmdline.isEmpty() || !_firstrun.isEmpty())
+    if (!_config.isEmpty() || !_cmdline.isEmpty() || !_firstrun.isEmpty() || !_cloudinit.isEmpty())
     {
         if (!_customizeImage())
         {
