@@ -4,34 +4,43 @@
 <context>
     <name>DownloadExtractThread</name>
     <message>
-        <location filename="../downloadextractthread.cpp" line="171"/>
-        <source>Error writing to storage</source>
-        <translation>저장소에 쓰는 중 오류 발생</translation>
-    </message>
-    <message>
-        <location filename="../downloadextractthread.cpp" line="197"/>
-        <location filename="../downloadextractthread.cpp" line="386"/>
+        <location filename="../downloadextractthread.cpp" line="196"/>
+        <location filename="../downloadextractthread.cpp" line="385"/>
         <source>Error extracting archive: %1</source>
         <translation>보관 파일 추출 오류: %1</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="262"/>
+        <location filename="../downloadextractthread.cpp" line="261"/>
         <source>Error mounting FAT32 partition</source>
         <translation>FAT32 파티션 마운트 오류</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="282"/>
+        <location filename="../downloadextractthread.cpp" line="281"/>
         <source>Operating system did not mount FAT32 partition</source>
         <translation>운영 체제에서 FAT32 파티션을 마운트하지 않음</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="305"/>
+        <location filename="../downloadextractthread.cpp" line="304"/>
         <source>Error changing to directory &apos;%1&apos;</source>
         <translation>디렉토리 변경 오류 &apos;%1&apos;</translation>
     </message>
+    <message>
+        <source>Error writing to storage</source>
+        <translation type="vanished">저장소에 쓰는 중 오류 발생</translation>
+    </message>
 </context>
 <context>
     <name>DownloadThread</name>
+    <message>
+        <location filename="../downloadthread.cpp" line="118"/>
+        <source>unmounting drive</source>
+        <translation>드라이브 마운트 해제</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="138"/>
+        <source>opening drive</source>
+        <translation>드라이브 열기</translation>
+    </message>
     <message>
         <location filename="../downloadthread.cpp" line="166"/>
         <source>Error running diskpart: %1</source>
@@ -78,10 +87,72 @@
         <translation>MBR을 zero&apos;ing out 하는 동안 쓰기 오류 발생 </translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="813"/>
+        <location filename="../downloadthread.cpp" line="319"/>
+        <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
+        <translation>SD card의 마지막 부분을 비워내는 동안 오류가 발생했습니다.&lt;br&gt;카드가 잘못된 용량을 표기하고 있을 수 있습니다(위조 품목).</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="408"/>
+        <source>starting download</source>
+        <translation>다운로드 시작</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="466"/>
+        <source>Error downloading: %1</source>
+        <translation>다운로드 중 오류: %1</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="663"/>
+        <source>Access denied error while writing file to disk.</source>
+        <translation>디스크에 파일을 쓰는 동안 액세스 거부 오류가 발생했습니다.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="668"/>
+        <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
+        <translation>제어된 폴더 액세스가 설정된 것 같습니다. rpi-imager.exe 및 fat32format.exe를 허용된 앱 리스트에서 추가하고 다시 시도하십시오.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="675"/>
+        <source>Error writing file to disk</source>
+        <translation>디스크에 파일 쓰기 오류</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="697"/>
+        <source>Download corrupt. Hash does not match</source>
+        <translation>다운로드가 손상되었습니다. 해시가 일치하지 않습니다.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="709"/>
+        <location filename="../downloadthread.cpp" line="761"/>
+        <source>Error writing to storage (while flushing)</source>
+        <translation>저장소에 쓰는 중 오류 발생(flushing..)</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="716"/>
+        <location filename="../downloadthread.cpp" line="768"/>
+        <source>Error writing to storage (while fsync)</source>
+        <translation>스토리지에 쓰는 중 오류 발생(fsync..)</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="751"/>
+        <source>Error writing first block (partition table)</source>
+        <translation>첫 번째 블록을 쓰는 중 오류 발생 (파티션 테이블)</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="826"/>
         <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
         <translation>저장소에서 읽는 동안 오류가 발생했습니다.&lt;br&gt;SD 카드가 고장 났을 수 있습니다.</translation>
     </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="845"/>
+        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
+        <translation>쓰기를 확인하지 못했습니다. SD카드 내용과 쓰인 내용이 다릅니다.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="898"/>
+        <source>Customizing image</source>
+        <translation>이미지 사용자 정의</translation>
+    </message>
     <message>
         <source>Waiting for FAT partition to be mounted</source>
         <translation type="vanished">FAT 파티션이 마운트되기를 기다리는 중</translation>
@@ -98,11 +169,6 @@
         <source>Unable to customize. File &apos;%1&apos; does not exist.</source>
         <translation type="vanished">지정할 수 없습니다. 파일이 &apos;%1&apos; 존재하지 않습니다.</translation>
     </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="885"/>
-        <source>Customizing image</source>
-        <translation>이미지 사용자 정의</translation>
-    </message>
     <message>
         <source>Error creating firstrun.sh on FAT partition</source>
         <translation type="vanished">FAT 파티션에 firstrun.sh을 만드는 동안 오류 발생</translation>
@@ -123,73 +189,6 @@
         <source>Error writing to cmdline.txt on FAT partition</source>
         <translation type="vanished">FAT 파티션에 cmdline.txt 쓰던 중 오류 발생</translation>
     </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="451"/>
-        <source>Access denied error while writing file to disk.</source>
-        <translation>디스크에 파일을 쓰는 동안 액세스 거부 오류가 발생했습니다.</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="456"/>
-        <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
-        <translation>제어된 폴더 액세스가 설정된 것 같습니다. rpi-imager.exe 및 fat32format.exe를 허용된 앱 리스트에서 추가하고 다시 시도하십시오.</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="463"/>
-        <source>Error writing file to disk</source>
-        <translation>디스크에 파일 쓰기 오류</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="482"/>
-        <source>Error downloading: %1</source>
-        <translation>다운로드 중 오류: %1</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="705"/>
-        <location filename="../downloadthread.cpp" line="757"/>
-        <source>Error writing to storage (while flushing)</source>
-        <translation>저장소에 쓰는 중 오류 발생(flushing..)</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="712"/>
-        <location filename="../downloadthread.cpp" line="764"/>
-        <source>Error writing to storage (while fsync)</source>
-        <translation>스토리지에 쓰는 중 오류 발생(fsync..)</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="693"/>
-        <source>Download corrupt. Hash does not match</source>
-        <translation>다운로드가 손상되었습니다. 해시가 일치하지 않습니다.</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="118"/>
-        <source>unmounting drive</source>
-        <translation>드라이브 마운트 해제</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="138"/>
-        <source>opening drive</source>
-        <translation>드라이브 열기</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="319"/>
-        <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
-        <translation>SD card의 마지막 부분을 비워내는 동안 오류가 발생했습니다.&lt;br&gt;카드가 잘못된 용량을 표기하고 있을 수 있습니다(위조 품목).</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="408"/>
-        <source>starting download</source>
-        <translation>다운로드 시작</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="747"/>
-        <source>Error writing first block (partition table)</source>
-        <translation>첫 번째 블록을 쓰는 중 오류 발생 (파티션 테이블)</translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="832"/>
-        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
-        <translation>쓰기를 확인하지 못했습니다. SD카드 내용과 쓰인 내용이 다릅니다.</translation>
-    </message>
 </context>
 <context>
     <name>DriveFormatThread</name>
@@ -274,7 +273,7 @@
         <translation>이미지 선택하기</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="864"/>
+        <location filename="../imagewriter.cpp" line="896"/>
         <source>Would you like to prefill the wifi password from the system keychain?</source>
         <translation>wifi password를 미리 입력하시겠습니까?</translation>
     </message>
@@ -318,131 +317,138 @@
 <context>
     <name>OptionsPopup</name>
     <message>
-        <location filename="../OptionsPopup.qml" line="80"/>
-        <source>Advanced options</source>
-        <translation>고급 옵션</translation>
+        <location filename="../OptionsPopup.qml" line="20"/>
+        <source>OS Customization</source>
+        <translation>OS 커스터마이징</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="97"/>
-        <source>Image customization options</source>
-        <translation>이미지 사용자 정의 옵션</translation>
+        <location filename="../OptionsPopup.qml" line="52"/>
+        <source>OS customization options</source>
+        <translation>OS 커스터마이징 옵션</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="105"/>
+        <location filename="../OptionsPopup.qml" line="57"/>
         <source>for this session only</source>
         <translation>이 세션에 한하여</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="106"/>
+        <location filename="../OptionsPopup.qml" line="58"/>
         <source>to always use</source>
         <translation>항상 사용</translation>
     </message>
     <message>
-        <source>Disable overscan</source>
-        <translation type="vanished">overscan 사용 안 함</translation>
+        <location filename="../OptionsPopup.qml" line="71"/>
+        <source>General</source>
+        <translation>일반</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="120"/>
+        <location filename="../OptionsPopup.qml" line="79"/>
+        <source>Services</source>
+        <translation>서비스</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="82"/>
+        <source>Options</source>
+        <translation>옵션</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="98"/>
         <source>Set hostname:</source>
         <translation>hostname 설정:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="140"/>
-        <source>Enable SSH</source>
-        <translation>SSH 사용</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="162"/>
-        <source>Use password authentication</source>
-        <translation>비밀번호 인증 사용</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="172"/>
-        <source>Allow public-key authentication only</source>
-        <translation>공개 키만 인증 허용</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="190"/>
-        <source>Set authorized_keys for &apos;%1&apos;:</source>
-        <translation>&apos;%1&apos; 인증키 설정:</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="264"/>
-        <source>Configure wireless LAN</source>
-        <translation>무선 LAN 설정</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="283"/>
-        <source>SSID:</source>
-        <translation>SSID:</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="237"/>
-        <location filename="../OptionsPopup.qml" line="303"/>
-        <source>Password:</source>
-        <translation>비밀번호:</translation>
-    </message>
-    <message>
-        <location filename="../OptionsPopup.qml" line="203"/>
+        <location filename="../OptionsPopup.qml" line="120"/>
         <source>Set username and password</source>
         <translation>사용자 이름 및 비밀번호 설정</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="222"/>
+        <location filename="../OptionsPopup.qml" line="142"/>
         <source>Username:</source>
         <translation>사용자 이름:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="298"/>
-        <source>Hidden SSID</source>
-        <translation>숨겨진 SSID</translation>
+        <location filename="../OptionsPopup.qml" line="158"/>
+        <location filename="../OptionsPopup.qml" line="219"/>
+        <source>Password:</source>
+        <translation>비밀번호:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="319"/>
+        <location filename="../OptionsPopup.qml" line="186"/>
+        <source>Configure wireless LAN</source>
+        <translation>무선 LAN 설정</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="205"/>
+        <source>SSID:</source>
+        <translation>SSID:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="238"/>
         <source>Show password</source>
         <translation>비밀번호 표시</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="324"/>
+        <location filename="../OptionsPopup.qml" line="244"/>
+        <source>Hidden SSID</source>
+        <translation>숨겨진 SSID</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="250"/>
         <source>Wireless LAN country:</source>
         <translation>무선 LAN 국가:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="335"/>
+        <location filename="../OptionsPopup.qml" line="261"/>
         <source>Set locale settings</source>
         <translation>로케일 설정 지정</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="345"/>
+        <location filename="../OptionsPopup.qml" line="271"/>
         <source>Time zone:</source>
         <translation>시간대:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="355"/>
+        <location filename="../OptionsPopup.qml" line="281"/>
         <source>Keyboard layout:</source>
         <translation>키보드 레이아웃:</translation>
     </message>
     <message>
-        <source>Skip first-run wizard</source>
-        <translation type="vanished">초기 실행 마법사 건너뛰기</translation>
+        <location filename="../OptionsPopup.qml" line="298"/>
+        <source>Enable SSH</source>
+        <translation>SSH 사용</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="368"/>
-        <source>Persistent settings</source>
-        <translation>영구적으로 설정</translation>
+        <location filename="../OptionsPopup.qml" line="317"/>
+        <source>Use password authentication</source>
+        <translation>비밀번호 인증 사용</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="376"/>
+        <location filename="../OptionsPopup.qml" line="327"/>
+        <source>Allow public-key authentication only</source>
+        <translation>공개 키만 인증 허용</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="345"/>
+        <source>Set authorized_keys for &apos;%1&apos;:</source>
+        <translation>&apos;%1&apos; 인증키 설정:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="357"/>
+        <source>RUN SSH-KEYGEN</source>
+        <translation>SSH-KEYGEN 실행</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="375"/>
         <source>Play sound when finished</source>
         <translation>완료되면 효과음으로 알림</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="380"/>
+        <location filename="../OptionsPopup.qml" line="379"/>
         <source>Eject media when finished</source>
         <translation>완료되면 미디어 꺼내기</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="384"/>
+        <location filename="../OptionsPopup.qml" line="383"/>
         <source>Enable telemetry</source>
         <translation>이미지 다운로드 통계 관하여 정보 수집 허용</translation>
     </message>
@@ -451,11 +457,23 @@
         <source>SAVE</source>
         <translation>저장</translation>
     </message>
+    <message>
+        <source>Disable overscan</source>
+        <translation type="vanished">overscan 사용 안 함</translation>
+    </message>
+    <message>
+        <source>Skip first-run wizard</source>
+        <translation type="vanished">초기 실행 마법사 건너뛰기</translation>
+    </message>
+    <message>
+        <source>Persistent settings</source>
+        <translation type="vanished">영구적으로 설정</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../linux/linuxdrivelist.cpp" line="111"/>
+        <location filename="../linux/linuxdrivelist.cpp" line="119"/>
         <source>Internal SD card reader</source>
         <translation>내장 SD 카드 리더기</translation>
     </message>
@@ -464,31 +482,31 @@
     <name>UseSavedSettingsPopup</name>
     <message>
         <location filename="../UseSavedSettingsPopup.qml" line="73"/>
-        <source>Warning: advanced settings set</source>
-        <translation>경고: 고급 설정이 설정됨</translation>
+        <source>Use OS customization?</source>
+        <translation>OS 커스터마이징을 사용하십니까?</translation>
     </message>
     <message>
         <location filename="../UseSavedSettingsPopup.qml" line="87"/>
-        <source>Would you like to apply the image customization settings saved earlier?</source>
-        <translation>이전에 저장한 이미지 사용자 지정 설정을 적용하시겠습니까?</translation>
+        <source>Would you like to apply OS customization settings?</source>
+        <translation>OS 커스터마이징 설정을 적용하시겠습니까?</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="96"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="97"/>
         <source>NO</source>
         <translation>아니요</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="106"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="107"/>
         <source>NO, CLEAR SETTINGS</source>
         <translation>아니요, 설정 지우기</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="116"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="117"/>
         <source>YES</source>
         <translation>예</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="126"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="127"/>
         <source>EDIT SETTINGS</source>
         <translation>설정을 편집하기</translation>
     </message>
@@ -496,257 +514,288 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="24"/>
+        <location filename="../main.qml" line="22"/>
         <source>Raspberry Pi Imager v%1</source>
         <translation>Raspberry Pi Imager v%1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="99"/>
-        <location filename="../main.qml" line="399"/>
+        <location filename="../main.qml" line="114"/>
+        <location filename="../main.qml" line="467"/>
+        <source>Raspberry Pi Device</source>
+        <translation>라즈베리파이(Raspberry Pi) 디바이스</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
+        <source>CHOOSE DEVICE</source>
+        <translation>장치 선택</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="138"/>
+        <source>Select this button to choose your target Raspberry Pi</source>
+        <translation>이 버튼을 선택하면 타켓 Raspberry Pi 를 선택할 수 있습니다</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="97"/>
+        <location filename="../main.qml" line="413"/>
         <source>Operating System</source>
         <translation>운영체제</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="109"/>
         <source>CHOOSE OS</source>
         <translation>운영체제 선택</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="123"/>
+        <location filename="../main.qml" line="121"/>
         <source>Select this button to change the operating system</source>
         <translation>운영 체제를 변경하려면 이 버튼을 선택합니다.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="135"/>
-        <location filename="../main.qml" line="713"/>
+        <location filename="../main.qml" line="133"/>
+        <location filename="../main.qml" line="780"/>
         <source>Storage</source>
         <translation>저장소</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="147"/>
-        <location filename="../main.qml" line="1041"/>
+        <location filename="../main.qml" line="145"/>
+        <location filename="../main.qml" line="1108"/>
         <source>CHOOSE STORAGE</source>
         <translation>저장소 선택</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="173"/>
+        <location filename="../main.qml" line="171"/>
         <source>WRITE</source>
         <translation>쓰기</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="177"/>
-        <source>Select this button to start writing the image</source>
-        <translation>이미지 쓰기를 시작하려면 버튼을 선택합니다.</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="218"/>
-        <source>CANCEL WRITE</source>
-        <translation>쓰기 취소</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="221"/>
-        <location filename="../main.qml" line="968"/>
-        <source>Cancelling...</source>
-        <translation>취소 하는 중...</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="229"/>
-        <source>CANCEL VERIFY</source>
-        <translation>확인 취소</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="232"/>
-        <location filename="../main.qml" line="991"/>
-        <location filename="../main.qml" line="1060"/>
-        <source>Finalizing...</source>
-        <translation>마무리 중...</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="247"/>
-        <source>Select this button to access advanced settings</source>
-        <translation>고급 설정에 액세스하려면 버튼을 선택합니다.</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="261"/>
-        <source>Using custom repository: %1</source>
-        <translation>사용자 지정 리포지토리 사용: %1</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="270"/>
-        <source>Keyboard navigation: &lt;tab&gt; navigate to next button &lt;space&gt; press button/select item &lt;arrow up/down&gt; go up/down in lists</source>
-        <translation>키보드 탐색: &lt;tab&gt; 다음 버튼으로 이동 &lt;space&gt; 버튼 선택 및 항목 선택 &lt;arrow up/down&gt; 목록에서 위아래로 이동</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="290"/>
-        <source>Language: </source>
-        <translation>언어: </translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="313"/>
-        <source>Keyboard: </source>
-        <translation>키보드: </translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="505"/>
-        <location filename="../main.qml" line="1025"/>
-        <source>Erase</source>
-        <translation>삭제</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="506"/>
-        <source>Format card as FAT32</source>
-        <translation>FAT32로 카드 형식 지정</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="515"/>
-        <source>Use custom</source>
-        <translation>사용자 정의 사용</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="516"/>
-        <source>Select a custom .img from your computer</source>
-        <translation>컴퓨터에서 사용자 지정 .img를 선택합니다.</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="461"/>
-        <source>Back</source>
-        <translation>뒤로 가기</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="157"/>
+        <location filename="../main.qml" line="155"/>
         <source>Select this button to change the destination storage device</source>
         <translation>저장 디바이스를 변경하려면 버튼을 선택합니다.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="462"/>
+        <location filename="../main.qml" line="216"/>
+        <source>CANCEL WRITE</source>
+        <translation>쓰기 취소</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="219"/>
+        <location filename="../main.qml" line="1035"/>
+        <source>Cancelling...</source>
+        <translation>취소 하는 중...</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="227"/>
+        <source>CANCEL VERIFY</source>
+        <translation>확인 취소</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="230"/>
+        <location filename="../main.qml" line="1058"/>
+        <location filename="../main.qml" line="1127"/>
+        <source>Finalizing...</source>
+        <translation>마무리 중...</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="288"/>
+        <source>Next</source>
+        <translation>다음</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="175"/>
+        <source>Select this button to start writing the image</source>
+        <translation>이미지 쓰기를 시작하려면 버튼을 선택합니다.</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="245"/>
+        <source>Select this button to access advanced settings</source>
+        <translation>고급 설정에 액세스하려면 버튼을 선택합니다.</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="259"/>
+        <source>Using custom repository: %1</source>
+        <translation>사용자 지정 리포지토리 사용: %1</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="268"/>
+        <source>Keyboard navigation: &lt;tab&gt; navigate to next button &lt;space&gt; press button/select item &lt;arrow up/down&gt; go up/down in lists</source>
+        <translation>키보드 탐색: &lt;tab&gt; 다음 버튼으로 이동 &lt;space&gt; 버튼 선택 및 항목 선택 &lt;arrow up/down&gt; 목록에서 위아래로 이동</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="289"/>
+        <source>Language: </source>
+        <translation>언어: </translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="312"/>
+        <source>Keyboard: </source>
+        <translation>키보드: </translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="437"/>
+        <source>Pi model:</source>
+        <translation>파이 모델</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="448"/>
+        <source>[ All ]</source>
+        <translation>[ 전체 ]</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="528"/>
+        <source>Back</source>
+        <translation>뒤로 가기</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="529"/>
         <source>Go back to main menu</source>
         <translation>기본 메뉴로 돌아가기</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="628"/>
+        <location filename="../main.qml" line="695"/>
         <source>Released: %1</source>
         <translation>릴리즈: %1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="638"/>
+        <location filename="../main.qml" line="705"/>
         <source>Cached on your computer</source>
         <translation>컴퓨터에 캐시됨</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="640"/>
+        <location filename="../main.qml" line="707"/>
         <source>Local file</source>
         <translation>로컬 파일</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="641"/>
+        <location filename="../main.qml" line="708"/>
         <source>Online - %1 GB download</source>
         <translation>온라인 - %1 GB 다운로드</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="766"/>
-        <location filename="../main.qml" line="818"/>
-        <location filename="../main.qml" line="824"/>
+        <location filename="../main.qml" line="833"/>
+        <location filename="../main.qml" line="885"/>
+        <location filename="../main.qml" line="891"/>
         <source>Mounted as %1</source>
         <translation>%1로 마운트</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="820"/>
+        <location filename="../main.qml" line="887"/>
         <source>[WRITE PROTECTED]</source>
         <translation>[쓰기 보호됨]</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="862"/>
+        <location filename="../main.qml" line="929"/>
         <source>Are you sure you want to quit?</source>
         <translation>정말 그만두시겠습니까?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="863"/>
+        <location filename="../main.qml" line="930"/>
         <source>Raspberry Pi Imager is still busy.&lt;br&gt;Are you sure you want to quit?</source>
         <translation>Raspberry Pi Imager가 사용 중입니다.&lt;br&gt;정말 그만두시겠습니까?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="874"/>
+        <location filename="../main.qml" line="941"/>
         <source>Warning</source>
         <translation>주의</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="882"/>
+        <location filename="../main.qml" line="949"/>
         <source>Preparing to write...</source>
         <translation>쓰기 준비 중...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="906"/>
-        <source>Update available</source>
-        <translation>업데이트 가능</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="907"/>
-        <source>There is a newer version of Imager available.&lt;br&gt;Would you like to visit the website to download it?</source>
-        <translation>Raspberry Pi Imager의 최신 버전을 사용할 수 있습니다.&lt;br&gt;다운받기 위해 웹사이트를 방문하시겠습니까??</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="971"/>
-        <source>Writing... %1%</source>
-        <translation>쓰는 중... %1%</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="895"/>
+        <location filename="../main.qml" line="962"/>
         <source>All existing data on &apos;%1&apos; will be erased.&lt;br&gt;Are you sure you want to continue?</source>
         <translation>&apos;%1&apos;에 존재하는 모든 데이터가 지워집니다.&lt;br&gt;계속하시겠습니까?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="950"/>
+        <location filename="../main.qml" line="973"/>
+        <source>Update available</source>
+        <translation>업데이트 가능</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="974"/>
+        <source>There is a newer version of Imager available.&lt;br&gt;Would you like to visit the website to download it?</source>
+        <translation>Raspberry Pi Imager의 최신 버전을 사용할 수 있습니다.&lt;br&gt;다운받기 위해 웹사이트를 방문하시겠습니까??</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1017"/>
         <source>Error downloading OS list from Internet</source>
         <translation>인터넷에서 OS 목록을 다운로드하는 중 오류 발생</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="994"/>
+        <location filename="../main.qml" line="1038"/>
+        <source>Writing... %1%</source>
+        <translation>쓰는 중... %1%</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1061"/>
         <source>Verifying... %1%</source>
         <translation>확인 중... %1%</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1001"/>
+        <location filename="../main.qml" line="1068"/>
         <source>Preparing to write... (%1)</source>
         <translation>쓰기 준비 중... (%1)</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1017"/>
+        <location filename="../main.qml" line="1084"/>
         <source>Error</source>
         <translation>오류</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1024"/>
+        <location filename="../main.qml" line="1091"/>
         <source>Write Successful</source>
         <translation>쓰기 완료</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1026"/>
+        <location filename="../main.qml" line="572"/>
+        <location filename="../main.qml" line="1092"/>
+        <source>Erase</source>
+        <translation>삭제</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1093"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been erased&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; 가 지워졌습니다.&lt;br&gt;&lt;br&gt;이제 SD card를 제거할 수 있습니다.</translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="1100"/>
+        <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
+        <translation>&lt;b&gt;%1&lt;/b&gt;가 &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;에 쓰여졌습니다. 이제 SD card를 제거할 수 있습니다.</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1202"/>
+        <source>Error parsing os_list.json</source>
+        <translation>구문 분석 오류 os_list.json</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="573"/>
+        <source>Format card as FAT32</source>
+        <translation>FAT32로 카드 형식 지정</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="582"/>
+        <source>Use custom</source>
+        <translation>사용자 정의 사용</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="583"/>
+        <source>Select a custom .img from your computer</source>
+        <translation>컴퓨터에서 사용자 지정 .img를 선택합니다.</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1391"/>
+        <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
+        <translation>먼저 이미지가 들어 있는 USB를 연결합니다.&lt;br&gt;이미지는 USB 루트 폴더에 있어야 합니다.</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1407"/>
+        <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
+        <translation>쓰기 금지된 SD card&lt;br&gt;카드 왼쪽에 있는 잠금 스위치를 위쪽으로 누른 후 다시 시도하십시오.</translation>
+    </message>
     <message>
         <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;</source>
         <translation type="vanished">&lt;b&gt;%1&lt;/b&gt;가 &lt;b&gt;%2&lt;/b&gt;에 쓰여졌습니다.</translation>
     </message>
-    <message>
-        <location filename="../main.qml" line="1033"/>
-        <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
-        <translation>&lt;b&gt;%1&lt;/b&gt;가 &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;에 쓰여졌습니다. 이제 SD card를 제거할 수 있습니다.</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="1101"/>
-        <source>Error parsing os_list.json</source>
-        <translation>구문 분석 오류 os_list.json</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="1274"/>
-        <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
-        <translation>먼저 이미지가 들어 있는 USB를 연결합니다.&lt;br&gt;이미지는 USB 루트 폴더에 있어야 합니다.</translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="1290"/>
-        <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
-        <translation>쓰기 금지된 SD card&lt;br&gt;카드 왼쪽에 있는 잠금 스위치를 위쪽으로 누른 후 다시 시도하십시오.</translation>
-    </message>
 </context>
 </TS>
